#!/bin/sh
# Run this to generate all the initial makefiles, etc.

srcdir=`dirname $0`
test -z "$srcdir" && srcdir=.

PKG_NAME="Gnome Data Access"

(test -f $srcdir/configure.in \
  && test -d $srcdir/gda \
  && test -f $srcdir/gda/gda.idl) || {
    echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
    echo " top-level gnome-filer directory"
    exit 1
}

. $srcdir/macros/autogen.sh
